@@ -9,7 +9,7 @@ from enum import Enum
 __all__ = ['PropertyValueInput', 'PlaceInput', 'LocationInput', 'PersonIdentifierInput', 'OrganizationInput',
            'PersonInput', 'ThingInput', 'PersonOrThingInput', 'CreateCIDInput', 'UpdateCIDInput',
            'AssignIdentifierInput', 'IdentifierTypeInput', 'ExtractFullTextInput', 'CallbackInput', 'HttpMethodInput',
-           'SetArchivalCopyUrlInput']
+           'SetArchivalCopyUrlInput', 'ExtractFragmentsInput']
 
 CID_PREFIX = '20.500.12592'
 
